---
title: "Two Concepts of Free Speech"
author: "Philip Pettit"
image: /img/philip-pettit.jpg
era: "Contemporary"
topic: "Free Speech"
draft: false
---

*This post is an excerpt from: [Pettit, P 2018, ‘Two Concepts of Free Speech’, in Jennifer Lackey (ed.), \*Academic Freedom\*, Oxford University Press, Oxford, UK, pp. 61-81pp.](https://researchers.anu.edu.au/publications/140017)*

…all agree... that free speech exists only to the extent that there is considerable latitude in speakers’ choices about what to say. And they debate in detail about the precise extent of the required latitude. But they say little or nothing on what it is about choices in that range of speech that makes them free.

…there are two distinct grounds on which speech in the relevant range might be taken to be free. The first is that people are *unhindered* in how they exercise their speech options within that range. The second is that they are *protected* in the exercise of those options: in particular, that they are protected by public law or by the public rules of a corporate body like a university, which has its own domain and government…

*Unhindered Speech*

Unhindered speech, as the phrase suggests, is speech that you can conduct without facing hindrance from other individuals or from any officials, whether they be officials of the state or officials in a corporate body that has its own internal government and regulations. Speech can be hindered in any of a number of ways. Covertly or overtly, others may remove your option of saying what you want to say. Covertly or overtly, they may impose a penalty on your saying it: that is, replace the option by a penalized alternative. Or finally—and necessarily, of course in a covert way—they may deceive you about the chance or need to say it, thereby misrepresenting the option. In short, the hindrance of others in the domain of speech, as in any other domain, may involve removing, replacing, or misrepresenting the options before you.

Even with these clarifications in place, however, there are two different ways in which the requirements of unhindered speech may be understood. You may be taken to enjoy free speech in this sense just so long as you are allowed to say what you actually want to say on a given occasion. Thomas Hobbes (1994, ch. 21.2) would presumably take this to be enough for unhindered speech, as he says that someone is free—and presumably, therefore, free in speech—when “he is not hindered to do what he has a will to”: that is, not hindered to do what he actually wishes to do.

This reading of what it is to enjoy unhindered speech would equate it with enjoying preference-satisfaction in the realm of speech. It puts a premium on being able to speak as you actually wish to speak, without requiring that you would also have been able to act according to your wishes, had you wanted to say something else or wanted indeed to stay silent. Think of the different expressive options you face in such a situation as doors between which you have to choose. On Hobbes’s view, you enjoy freedom of speech insofar as the door you push on—the option you actually prefer—is open to you. It does not require that any of the other doors are open, just the one you choose.

Isaiah Berlin offers an alternative vision of what unhindered speech requires, defending precisely the sort of open-doors picture that Hobbes rejects. According to this account you enjoy free speech on a given occasion just to the extent that all the relevant options or doors, and not just the one you prefer, are open to you. You may choose to speak out in a particular way and find, happily, that that door is open; no one tries to stop you. But it also has to be the case, on this account of unhindered speech, that if you had chosen to say something else instead, or chosen not to speak at all, then that door would also have been open. “The extent of a man’s negative freedom is, as it were, a function of what doors, and how many are open to him; upon what prospects they are open; and how open they are” (Berlin 1969, p. xlviii).

Berlin’s conception of unhindered action or speech is clearly superior to that of Hobbes. For as he points out, you could give yourself Hobbesian freedom of speech, even when you are blocked from saying what you want to say, by getting yourself to change what you want to say: by adapting your preferences. And that does seem downright absurd; it falls far short of our intuitive sense of what the ideal of freedom should ensure. He underlines this normative absurdity quite nicely when he notes: “to teach a man that, if he cannot get what he wants, he must learn to want only what he can get may contribute to his happiness or his security; but it will not increase his civil or political freedom” (Berlin 1969, p. xxxix).

The Hobbesian conception of free speech requires the absence of frustration: you get to say what you actually prefer to say in the context of certain options. The Berlinian requires the absence of interference, as we might put it: you get to say whatever you might want to say, regardless of the option you prefer. Freedom in the sense of non-interference is a more demanding ideal of free speech than freedom in the sense of non-frustration, and from now on we can identify it with the ideal of unhindered speech. But, even interpreted in this way, the ideal of unhindered speech is itself less demanding than the ideal of protected speech.

*Protected Speech*

Taking unhindered speech in Berlin’s sense, then, what distinguishes it from protected speech? Not much stands between them on a common but inadequate account of protection. On that account, the point of protection is to make it more likely that you will enjoy unhindered speech: to increase the expectation or probability of unhindered speech. The difference between unhindered and protected speech on this approach would simply be the difference between actual unhindered-speech and expected unhindered-speech. The same ideal would be at issue in each case but would be presented from different perspectives: in the first case, it would be cast *ex post* as a goal attained, in the second it would be cast *ex ante* as a goal to pursue.

But the point of protection is not just to probabilify in this way. After all, I might make your enjoyment of free speech more probable by bribing others to let you have your say and that would scarcely be a way of protecting you. What protective measures aim to achieve is not primarily to make your enjoyment of unhindered speech as likely as possible—after all, the bribery arrangement might actually do better on that front—but to put burdens in the way of others interfering with you: to render their interference not so much less likely as less accessible (Pettit 2008).

What form should those protective burdens take? Typically, they involve preventive obstacles that remove the option of interference altogether or, more plausibly, penalties that put difficulties or costs, actual or threatened, in the way of interference. In other words, they put in place measures of interference that counter the interference they are designed to block. Paying would-be interferers for not interfering would not interfere with them in this sense. It would put an extra alternative on their menu of options, allowing them not just the option of refraining from interference but the enhanced option of refraining and claiming the payment as reward. That would certainly make non-interference more attractive for them but it would leave the interference option intact; it would put nothing in the way of their taking it instead.

Protected speech appears as a distinct ideal from unhindered speech as soon as we recognize that the point of protection is not to make interference less attractive and less probable but to interfere with the very possibility of interference: to remove that option altogether or to replace it by a penalized alternative. Protecting you means erecting obstacles to the interference of other people in any scenarios, however improbable, where they might choose to try to interfere. And that is quite distinct from trying to make their interference less probable. Doing that would not necessarily mean arranging things so that would-be interferers are obstructed—that may not be the best means of reducing the probability of interference—but arranging things so that others are less likely to interfere. It would mean giving them something more attractive to do, such as refraining from interference and then claiming payment as a reward.

The protection of freedom of speech is always going to raise an issue, of course, as to who is in charge of the protective apparatus. I shall assume here that when protection is necessary—when there is no natural obstacle or hurdle stopping some from interfering with others—it is provided by law, with the support of social norms, and that that law is subject to democratic, constitutional control, not exposed to an unconstrained will on the part of those in power. In particular, I shall assume that the legal protection is not provided at the whim of a benevolent autocrat or elite body. If it were provided on such a discretionary basis then it would not be fully protective: it would protect you from others in the society, but only at the cost of leaving you unprotected against the even greater danger that such an authority would represent.

*Comparing unhindered and protected speech*

… The distinction drawn has deep-running practical implications, which bear on the social meaning of free speech and on the political appeal of protecting and regulating it. Conceived as unhindered, free speech is a socially undemanding and a politically problematic ideal. Conceived as protected, it contrasts on both counts: socially, it imposes demanding requirements; politically, it constitutes a plausible goal…

Unhindered speech is socially less demanding than protected speech because you can enjoy it just by virtue of others not actually interfering and not being likely to interfere. It does not matter that they have a power of interference against which you are not protected. So long as they do not actually impose on you, and are unlikely to do so, you have all the freedom of speech you could wish for. You may be a member of the beta class in a society where anyone in the alpha class can shut you up; you have no protection against them. But if those in the alpha class are indulgent towards you, letting you say what you wish, that means that you have the fullest form of freedom in this sense.

If free speech means protected speech, however, then that is not so. For, to stick with the scenario just introduced, the alphas who refrain from interfering with you or other beta speakers still retain the power of interference; it is not as if they renounce or destroy that capacity. And so, you as a beta are not protected against them. You could enjoy free speech in the richer, protected sense, only to the extent that interference by any alpha was not so much unlikely as inaccessible. Alphas would have to face serious obstacles if they tried to interfere, finding that the option of interference was blocked entirely or burdened by various difficulties or costs…

Unhindered speech is not only socially less demanding than protected speech; it is also politically more problematic. This is because any form of regulation, whether by officials of the state or of a subsidiary institution like a university, will be hostile as such to the ideal of unhindered speech: it will itself constitute a hindrance. A regulation against hate speech may do better overall by unhindered speech: it may prevent more interference than it perpetrates. But still, it will be hostile in itself to the ideal. While it may promise a number of steps forward in promoting free speech—this will always be a matter of relative probability—it will take one certain and decisive step backwards: it will itself impose on the freedom of certain speakers.

The crucial observation here, central to the tradition of classical liberalism, is in the words of Jeremy Bentham (1843, p. 503) that “all coercive laws …are, as far as they go, abrogative of liberty”: that is, liberty conceived as the absence of interference. The observation explains the sense in which the ideal of free, unhindered speech is politically dubious. It means that the onus is on regulators to argue that although their initiatives certainly reduce some free speech, those measures promise to do better by free speech in the longer term. The default option is no regulation, then. Regulation will be triggered only in response to positive evidence that it may be necessary for achieving the maximum level of free speech.

The ideal of free speech as protected speech is not politically problematic in the same way. On the contrary, it is an ideal that is entirely plausible, even inescapable, as a goal of law and regulation. It is only by dint of law and regulation—and supportive social norms—that speech gets to be protected, and gets to count as free. Assuming that the regime treats people as equals, as a public system will presumably be required to do, it will explicitly or implicitly protect those speech options that each can exercise and enjoy at the same time as others: those speech options, as we may say, that are co-exercisable and co-enjoyable (Pettit 2012, pp. 92–107).

*The Attractions of Equating Free Speech with Protected Speech*

The regulations designed to identify and protect co-exercisable, co-enjoyable speech options—the basic liberties of speech—may take any of a variety of forms. They will include regulations like Robert’s rules of order that prevent people speaking at will in a public gathering—and so avoid cacophony—but allow them to speak according to a certain schedule (Hart 1973). They will also include regulations that restrict speech options, criminalizing various forms of speech: for example, dangerous speech such as mischievously shouting “Fire!” in a crowded theater; speech that invades the privacy of others, as that is culturally understood; and the sort of hate speech that would threaten public order and undermine the peace that speech requires. And they may also include regulations that allow tort remedies against speech that would expose someone to an unjustified loss of reputation and standing. Such regulations are designed to identify speech options that can be protected for all at once, enabling each to exercise their options at the same time as others and regardless of how many others take up those options at the same time, to enjoy exercising them.

Although details of interpretation may be controversial, the regulations illustrated so far are all broadly plausible. But the requirement that the liberties of speech established in a society ought to include only speech options that are co-exercisable and co-enjoyable may argue for other, more surprising regulations.

Thus, to take a salient example, the requirement would argue, in my view, against allowing the sort of anonymous commercial and political speech that currently dominates social media. In order for each to enjoy the exercise of free speech by others, they must be able to hold those others to account, testing them for how far their speech represents the unified, fact-responsive viewpoint of a responsible speaker. But anonymity of the kind that currently prevails on social media makes speech entirely uncheckable and unaccountable. Denying hearers the ability to distinguish between responsible speech and fake speech, it threatens to reduce speech on the social media to the role of a manipulative instrument designed to get in under the radar of interrogation and elicit purely emotive responses.

The protection given to speech by the law may be provided in a number of ways. It may take the form of constitutional protection, as in the jurisdiction associated with the First Amendment of the United States. It may criminalize certain hindrances to speech. It may make measures of tort law available against purported hindrances, allowing plaintiffs to appeal to the courts. Or it may take a local form, as under the regulations of a particular institution like a university.

Thus, on the equation of free speech with protected speech, public law is essential both for identifying the speech options to be protected and for providing the protection itself; the law that plays this role may be common across a society or may apply only within a certain institutional context. And that means that suitable laws do not constitute an invasion of free speech from without—even an invasion that is benign overall—as the alternative approach assumes. It means that law is part of what creates free speech: part of the infrastructure necessary for people to share in enjoyment of that ideal.

If law is part of the infrastructure of free speech, of course, then the default position of those who embrace free speech cannot be no regulation. Rather it must be a commitment to identifying regulations that can provide the best infrastructure possible for free speech, protecting as many co-exercisable, co-enjoyable speech options as possible, establishing them as basic liberties of speech, and protecting those liberties in a suitably effective manner. What exact options should be protected as liberties, and in what measure they should be protected, is something for each legal system to determine, taking account of contextual and cultural considerations.

Even Isaiah Berlin (1969, p. lx) acknowledges the constructive role of the law on this front when he says that “the area of men’s free action” often has to be “artificially carved out” by law. While the idea may not appeal to those who insist on seeing free speech as unhindered speech, it also has the stamp of authority. John Locke (1960, II.57), the great apostle of tolerance, argued in this vein that “where there is no law, there is no freedom”: that it is the law that defines the range of relevant choices, including the choices you or I have to speak our mind, and that then gives them the protection required for freedom. And in taking this line, Locke was supported by legal and political authorities in the following century, prior to the rise of the classical liberal view that Bentham helped to shape. Thus, in his canonical commentary on English law in the 1760s, Sir William Blackstone (1978, p. 126) made a point that would have been endorsed on all sides: “laws, when prudently framed, are by no means subversive but rather introductive of liberty; for (as Mr Locke has well observed) where there is no law there is no freedom.”

References

- Bentham, J. 1843. Anarchical Fallacies. The Works of Jeremy Bentham, vol. 2, ed. J. Bowring. Edinburgh: W. Tait.
- Berlin, I. 1969. Four Essays on Liberty. Oxford, U.K.: Oxford University Press.
- Blackstone, W. 1978. Commentaries on the Laws of England. New York: Garland.
- Hobbes, T. 1994. Leviathan, ed. E. Curley. Indianapolis, IN: Hackett.
- Pettit, P. 2008. “Freedom and Probability: A Comment on Goodin and Jackson.” Philosophy and Public Affairs 36 (2): pp. 206–20.
- Pettit, P. 2012. On the People’s Terms: A Republican Theory and Model of Democracy. Cambridge, U.K.: Cambridge University Press.