---
title: "Why Should Speech Be Free?"
author: "Timothy Garton Ash"
image: /img/tim-ash.jpg
era: "Contemporary"
topic: "Free Speech"
draft: false
---

*The following is an excerpt from [“Free Speech: Ten Principles for A Connected World”](https://www.amazon.co.uk/Free-Speech-Principles-Connected-World-ebook/dp/B01B8H46NK/ref=sr_1_1?keywords=Free+Speech%3A+Ten+Principles+for+A+Connected+World&qid=1572685805&s=digital-text&sr=1-1), by Timothy Garton Ash*

**Why Should Speech Be Free?**

[W]hy should speech be free? As soon as we start trying to hold governments to their word, or debate the proper limits of free speech, we find ourselves reaching for arguments that either underpin or call into question the terms of such treaties, laws and policies. Even if your instinct, like mine, is to say, ‘but of course speech must be free!’ it is still important to spell out why.

The Western intellectual tradition has offered four main answers. Each comes with multiple philosophical, legal and literary variations, yet the basic thoughts are remarkably persistent. I call them in shorthand STGD: Self, Truth, Government, Diversity.

***Self***

The first argument is that we need freedom of expression to realise our full individual humanity. The power of speech is what distinguishes us from other animals and, thus far, from computers. If we are prevented from exercising it freely, we cannot fully be ourselves. That includes revealing ourselves to others, insofar as we wish to. Strapped into a straitjacket with a hood over my head and lips taped shut, I may inwardly reflect ‘my thoughts are free; you can’t take that away from me’. Yet even that innermost freedom of thought cannot entirely be separated from the freedom of expression. As anyone who writes or speaks will know, often you discover what you really think only in the process of speaking or writing. ‘The thought is made in the mouth’, said the Dadaist Tristan Tzara.1 Remember Syed Mahmood, spontaneously articulating to his home computer camera his reaction to the ‘Innocence of Muslims’ video.2 I will know what I definitely want to argue in this book only when I have finished writing it and discussed the draft with friends and critics.

Moreover, even the most unbending liberal individualist must accept, as a description of lived reality, that I establish not just what I think but who I am through relations with other people. The Zulu proverb umuntu ngumuntu ngabantu, which roughly translates as ‘a person is a person through other persons’, is sometimes understood as an African communitarian rebuke to European individualism, but it can simply be taken as the description of a human universal.3 It is precisely because we are not what Jeremy Waldron calls ‘the self-made atoms of liberal fantasy’ that we need the liberal good of freedom of expression, in communication with others, so as to be fully ourselves….

Thomas Scanlon derives the case for free speech from the essential sovereignty of the individual. In order that we may regard ourselves as ‘equal, autonomous, rational agents’, Scanlon writes, we must be ‘sovereign in deciding what to believe and in weighing competing reasons for action’.5 Note that this focuses on the right of the listener to hear competing arguments and beliefs, rather than that of the speaker to express something. (Needless to say, ‘speaker’ and ‘listener’ are terms of art, embracing all forms of communication.) When we judge any claim for free speech, we have to keep in mind and sometimes balance these two things: the rights of and consequences for the speaker, and the rights of and consequences for the listener. Simone’s couplet brilliantly captures both: ‘I wish you could know / what it means to be me’….

***Truth***

Scanlon takes us to the doorstep of a second classic argument for free speech, which is that it enables us to find the truth. Or at least it helps us to seek the truth. After a century of totalitarian lies, and faced with chronic media manipulation even in liberal democracies, we may no longer share the magnificent confidence of Milton’s ‘let her and Falsehood grapple; who ever knew Truth put to the worse in a free and open encounter?’ Even John Stuart Mill, who penned the most eloquent and influential version of the argument from truth in the English language, acknowledged that ‘it is a piece of idle sentimentality that truth, merely as truth, has any inherent power denied to error, of prevailing against the dungeon and the stake’. But Mill argues—against censorship—that a suppressed opinion may turn out to be true and that, even if not altogether true, it may yet contain some grain of truth. Even supposing the received wisdom is one hundred percent correct, if it is never challenged it will come to be held ‘in the manner of a prejudice’, or what another writer called ‘the deep slumber of a decided opinion’. ‘Both teachers and learners go to sleep at their post’, writes Mill, ‘as soon as there is no enemy in the field’.7 So the good sword of truth will only be kept sharp if it is constantly tried against the axes and bludgeons of falsehood.

The philosopher Bernard Williams acutely describes Mill’s notion as the ‘survival of the true’. It has had a huge influence on the whole Western tradition of thinking about freedom of expression.8 Together with his ‘harm principle’, it shapes free speech debates to this day. In the United States, this approach is characterised with the aid of another metaphor: the ‘marketplace of ideas’. The market comparison was popularised by the early-twentieth-century Supreme Court justice Oliver Wendell Holmes, although—as with so many famous quotations—he never used those exact words. But Holmes did argue, in a dissenting opinion in a 1919 Supreme Court case, ‘that the ultimate good desired is better reached by free trade in ideas—that the best test of truth is the power of the thought to get itself accepted in the competition of the market’. In a seminal article entitled ‘The Use of Knowledge in Society’, Friedrich Hayek made a lucid case for markets (as opposed to central planners) and especially what he called the ‘marvel’ of the price system being the best way to arrive at certain kinds of truth…

***Government***

A third classic argument for free speech is that it is necessary for good government. Although American universities have discarded the teleological ‘from Plato to NATO’ self-congratulation of once-obligatory courses on ‘Western Civ’, it remains astonishing how the essence of our modern idea of free speech as a democratic public good is to be found almost fully formed 2,500 years ago, in Athens and some Greek colonies across the seas. Every citizen who desired to do so would gather in the designated assembly place of the city-state. In Athens, some 6,000 people came together on the gentle slopes of the pnyx, just off the Acropolis.12 ‘Who wishes to address the assembly?’ cried the herald.13 Then any free man could speak, outlining what he believed would be the best policy for that city-state and presenting his reasons for it. The best decisions and policies, it was claimed, would be arrived at by openly debating the alternatives, often ending with a vote. The ancient Greeks named this novel form of government ‘democracy’, meaning rule by the people…

The ancient Greeks’ innovation of free speech for deliberative democracy embraces not one but two ideals, which they called parrhesia and isegoria. Parrhesia meant speech that was both free and fearless. The playwright Euripides has a mother wish that her sons should return to ‘glorious Athens, hold their heads high there, and speak their minds there like free men’. While the etymology of the word—from pan-rhesia, to say everything—might suggest unlimited speech, there was a strong presumption that the parrhesiast, the free-speaker, should say things he believed to be true and for the good of the community. The orator Demosthenes spoke of ‘the truth spoken with all freedom, simply in goodwill and for the best’. There was special licence for the arts, especially for comedy, but even Euripides deplored ‘hectoring and untutored parrhesia’.

As important was isegoria, which meant equality of speech—or what, in the modern language of rights, we would call an equal right to speak. In another of his plays, Euripides has Theseus, the mythical king of Athens, explain that ‘freedom lives in this formula: “Who has good counsel which he would offer the city?” He who desires to speak wins fame; he who does not is silent. Where could greater equality be found?’ To be sure, this ur-equality applied only to free men, not to women, noncitizens or slaves, but the essential idea was there. Free and equal speech would allow deliberative democracy and that, the ancient Athenians believed, would produce better government. Indeed, the historian Herodotus maintained that it was because Athens had free speech that it became powerful and victorious…

Pulling together some of these threads, an English judge wrote in a late-twentieth-century judgement that ‘freedom of speech is the lifeblood of democracy’. As Stephen Sedley points out, the word ‘lifeblood’ is particularly apt, since ‘free speech enables opinion and fact to be carried round the body politic’…

***Diversity***

A fourth major claim for free speech is particularly relevant to our emerging cosmopolis. Freedom of expression, it is argued, helps us to live with diversity. Although this strand does not figure so prominently in the modern Western classics on free speech, the germ of the idea is there at the very origins of modern liberalism. We can find it, for example, in the essays of John Locke and others about the need for ‘toleration’ in place of Europe’s wars of religion. We find it also in Immanuel Kant’s claim that human progress is best served not by the absence or suppression of conflict but by conducting that essential, creative conflict in peaceful, civilised ways.

The American scholar Lee Bollinger has developed this thought. Drawing on the experience of the United States, with its long history of religious and ethnic diversity, he suggests that freedom of expression ‘tests our ability to live in a society that is necessarily defined by conflict and controversy; it trains us in the art of tolerance and steels us for its vicissitudes’.28 One could put the same point more positively, circling back to the first argument for speech. If everyone living in the same place or space is free to express herself or himself, then we have a better chance of understanding what, in that memorable phrase sung by Nina Simone, ‘it means to be me’—and you, and her, and him; John, Aisha or Ming. We will not all choose to live our lives in the same way. We will not all agree. As Kant observed, human society would be stagnant and bovine if we did. (Adam and Eve were probably bored stiff in the Garden of Eden.) But we can learn, by practice, how to live with irreducible difference and not come to blows. At best, we will agree on how we disagree.

These four classic Western arguments—STGD—are combined by the former German Constitutional Court judge Dieter Grimm into a single pregnant formula: individual self-development and collective self-determination.